@@ -37,7 +37,7 @@ void get_hw_info(struct hw_info_type *hw_info,
 {
    FILE *fff;
    int cpus=0;
-   long long int mem;
+   long long mem;
    char temp_string2[BUFSIZ];
    char chip[BUFSIZ]="Unknown";
    char temp_string[BUFSIZ],bogomips_total[BUFSIZ]="???";
@@ -74,7 +74,7 @@ type  POWER2 Processor type  False
     pclose(fff);
 /* check mem, JSt */
     if ((fff=popen("lsattr -E -l sys0 -a realmem -F value","r") )!=NULL) {
-	     fscanf(fff,"%ld",&mem);
+	     fscanf(fff,"%lld",&mem);
 	  }
     pclose(fff);
   	    
