@@ -38,13 +38,13 @@ char *get_host_name(char *hostname,char *domain) {
        return uname_get_host_name(hostname,domain);
 }
 
-long int get_mem_size(void) {
+long long get_mem_size(void) {
    
    FILE *fff;
-   long size;
+   long long size;
    
    fff=popen("hinv -t memory","r");
-   fscanf(fff,"%*s%*s%*s %ld",&size);
+   fscanf(fff,"%*s%*s%*s %lld",&size);
    pclose(fff);
    return size;
 }
