@@ -61,6 +61,15 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
     if (strstr(model_string,"POWER3")!=NULL) {
        strncpy(cpu_info->chip_type,"POWER3",7);
     }
+    if (strstr(model_string,"POWER4")!=NULL) {
+       strncpy(cpu_info->chip_type,"POWER4",7);
+    }
+    if (strstr(model_string,"POWER5")!=NULL) {
+       strncpy(cpu_info->chip_type,"POWER5",7);
+    }
+    if (strstr(model_string,"POWER6")!=NULL) {
+       strncpy(cpu_info->chip_type,"POWER6",7);
+    }
    
        /* I Have an iBook now ;) */
     if (strstr(model_string,"745/755")!=NULL) {
@@ -132,12 +141,12 @@ int get_hardware(char *hardware_string) {
 }
 
     /* Some architectures might have better ways of detecting RAM size */
-long int get_arch_specific_mem_size(void) {
+long long get_arch_specific_mem_size(void) {
        /* We have no special way of detecting RAM */
    
        /* sysinfo is the only way that works on cell? */
        /* can we detect that somehow and force it? */
    
        /* For mac the meminfo way is definitely better */     
-       return -1;
+       return MEM_USE_MEMINFO;
 }
