@@ -211,6 +211,17 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
                   /* should catch the common case                  */
        strncpy(cpu_info->chip_vendor,"Centaur",8);
        
+       /* Should this be generic?  We should never print processor twice */
+       {
+	  char *processor_begin;
+          processor_begin=strstr(model_string," Processor");
+	  if (processor_begin!=NULL) {
+	     /* I hate to use pointer math */
+	    model_string[(processor_begin-model_string)]='\0';
+	  }
+       }
+
+   
           /* Is this the proper thing to do?  It looks silly */
           /* calling them "Centaur VIA" chips                */
        if (strstr(model_string,"VIA")!=NULL) {
@@ -329,13 +340,23 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
              /* TODO - determine base type based on model id? */
           if ( !(strncmp(model_string,"Intel(R) Xeon(TM) CPU",21)) ||
 	       !(strncmp(model_string,"Intel(R) Xeon(R) CPU",20)) || 
-	       !(strncmp(model_string,"Intel(R) Genuine CPU",19)) || 
+	       !(strncmp(model_string,"Intel(R) Genuine CPU",20)) || 
+	       !(strncmp(model_string,"Genuine Intel(R) CPU",20)) || 
 	       !(strncmp(model_string,"Intel(R) XEON(TM)",17)) ||
 	       !(strncmp(model_string,"Intel(R) Xeon(TM)",17))
 	      ) {
 	     strncpy(cpu_info->chip_type,"Pentium Xeon",16);
           }
-
+	     /* Nehalem */
+          if (strstr(model_string,"Core(TM) i7")!=NULL) {
+	     strncpy(cpu_info->chip_type,"i7",3);
+	  }
+          if (strstr(model_string,"Core(TM) i5")!=NULL) {
+	     strncpy(cpu_info->chip_type,"i5",3);
+	  }
+          if (strstr(model_string,"Core(TM) i3")!=NULL) {
+	     strncpy(cpu_info->chip_type,"i3",3);
+	  }
 	     /* Core and Core2 */
 	  if (strstr(model_string,"Core(TM)2 Duo")!=NULL) {
 	     strncpy(cpu_info->chip_type,"Core2 Duo",10);
@@ -397,6 +418,18 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
     if ( !(strncmp(vendor_string,"RiseRiseRise",12))) {
        strncpy(cpu_info->chip_vendor,"Rise",5);
     }
+
+       /* ************** */
+       /* SiS            */
+       /* ************** */
+    if ( !(strncmp(vendor_string,"SiS SiS SiS",11))) {
+       strncpy(cpu_info->chip_vendor,"SiS",4);
+       if (family!=0) {
+	  sprintf(temp_string,"%i86",family);
+          strncpy(cpu_info->chip_type,temp_string,4);
+       }
+    }
+
    
        /* ************* */
        /* Transmeta     */
@@ -420,6 +453,17 @@ int get_cpu_info(struct cpu_info_type *cpu_info) {
 	  strncpy(cpu_info->chip_type,"486SX",6);
        }
     }
+
+       /* ************** */
+       /* Vortex         */
+       /* ************** */
+    if ( !(strncmp(vendor_string,"Vortex86 SoC",11))) {
+       strncpy(cpu_info->chip_vendor,"Vortex",7);
+       if (family!=0) {
+	  sprintf(temp_string,"%i86",family);
+          strncpy(cpu_info->chip_type,temp_string,4);
+       }
+    }
    
        /* ****************************** */
        /* Try to handle cpus w/o cpuinfo */
@@ -460,7 +504,7 @@ int get_hardware_info(char *hardware_string) {
 }
 
     /* Some architectures might have better ways of detecting RAM size */
-long int get_arch_specific_mem_size(void) {
+long long get_arch_specific_mem_size(void) {
     /* We have no special way of detecting RAM */
-    return -1;
+    return 0;
 }
