@@ -4,16 +4,16 @@
 #include <string.h>
 #include <stdio.h>
 
-typedef struct {
+struct our_state {
     int pretty_printing;
-    int custom_cpuinfo;  
-    char cpuinfo_file[256];   
-} our_state;
+    int custom_cpuinfo;
+    char cpuinfo_file[BUFSIZ];
+};
 
-our_state internal_state={1,0,"/proc/cpuinfo"};
+struct our_state internal_state={1,0,"/proc/cpuinfo"};
 
 char *get_sysinfo_version(char *version) {
-    sprintf(version,"%i.%i.%i",VERSION_MAJOR,VERSION_MINOR,VERSION_SUBMINOR);
+    snprintf(version,BUFSIZ,"%i.%i.%i",VERSION_MAJOR,VERSION_MINOR,VERSION_SUBMINOR);
     return version;
 }
 
@@ -23,7 +23,7 @@ int get_numeric_sysinfo_version(void) {
 
 int set_cpuinfo_file(char *filename) {
     internal_state.custom_cpuinfo=1;
-    strncpy(internal_state.cpuinfo_file,filename,255);
+    strncpy(internal_state.cpuinfo_file,filename,BUFSIZ);
     return 0;
 }
 
